.. _user-guide:

User guide
============

Here is a list of example notebooks to illustrate how to use earthkit-data.


.. toctree::
    :maxdepth: 1
    :caption: User guide

    examples/01-introduction.ipynb
    examples/02-data-formats.ipynb
    examples/03-styles.ipynb
    examples/04-domains-and-coordinate-reference-systems.ipynb
    examples/05-input-grids.ipynb
